###################################
# May 11; GR                      #
# Models following Keele's advice #
###################################

source ("~/Documents/research/R_Latex_help/R_basic_functions.R")
library (survival); library (car); library (apsrtable);
library (boot); #library (frailtypack);
library (Amelia)

setwd ("~/Dropbox/bank_crises/Data/")
load ("amelia_imputation.RData")

# Source "function_combine_amelia_coxph" to be able to combine Amelia runs into a single table
source ("~/Documents/research/R_Latex_help/function_combine_amelia_coxph.R")

# The following function is useful to return countries with shared frailties
ReturnFrailtyNames <- function (Data, covariates.in.model) {
    valid.row <- ifelse (rowMeans (is.na(Data[, is.element(colnames(Data),covariates.in.model)]))==0, 1, 0)
    frailty.names <- unique (Data$ccname[valid.row==1])
    return (frailty.names)
}

variables.of.interest <- c("openk","kaopen","grgdpl2","step.inflation","POLCONV","polity2.y","presidential","rgdpl2","cumulative.bank.crises","allhouse","clarity.responsibility","bank.crisis.in.party.term","leave.risk.pool")

All.Data <- numeric (0)
for (i in 1:5)
{
   Data.Summary <- Imputed.Dataset[[1]][[i]][,colnames(Imputed.Dataset[[1]][[i]])%in%variables.of.interest]
   All.Data <- rbind (All.Data, Data.Summary)
}

All.Data$openk <- log (All.Data$openk)
All.Data$step.inflation <- log (All.Data$step.inflation)
All.Data$rgdpl2 <- log (All.Data$rgdpl2)


by (All.Data[,-grep("bank.crisis.in.party.term",colnames(All.Data))], as.factor (I(All.Data$bank.crisis.in.party.term>0)), mean)

by (All.Data[,-grep("bank.crisis.in.party.term",colnames(All.Data))], as.factor (I(All.Data$bank.crisis.in.party.term>0)), sd)


####################################################################################
# Openness covariate
####################################################################################
# this is the script of what one ought to do according to Keele 2010 (PA)
# Estimate model using splines for continuous independent variables
mod.international.1 <- coxph (Surv(enter.risk.pool, leave.risk.pool, party.death) ~ bank.crisis.in.party.term + pspline(openk) + pspline(kaopen) + pspline(grgdpl2) +  pspline(log(step.inflation)) + pspline(log (rgdpl2)) + cumulative.bank.crises + pspline(polity2.y) + presidential, data=Imputed.Dataset[[1]][[1]] ) 

summary (mod.international.1)  # reject non-linear (spline) specifications that do not achieve statistical significance

# Only the Polity2.y spline achieves significance
mod.international.1 <- coxph (Surv(enter.risk.pool, leave.risk.pool, party.death) ~ bank.crisis.in.party.term*openk + bank.crisis.in.party.term*kaopen + grgdpl2 +  log(step.inflation) + log (rgdpl2) + cumulative.bank.crises + pspline(polity2.y) + presidential, data=Imputed.Dataset[[1]][[1]] ) 

summary (mod.international.1)  # reject non-linear (spline)
cox.zph (mod.international.1)  # if there is evidence of non-proportionality, then it is necessary to interact offending variable with log.time
# Only presidential fails the test of proportionality at the 95% confidence level

# The next line is the model that one should fit, according to the evidence in the previous lines
mod.international.2 <- coxph (Surv(enter.risk.pool, leave.risk.pool, party.death) ~ bank.crisis.in.party.term*openk + bank.crisis.in.party.term*kaopen + grgdpl2 +  log(step.inflation) + log (rgdpl2) + cumulative.bank.crises + pspline(polity2.y) + presidential + I(presidential*log(leave.risk.pool)), data=Imputed.Dataset[[1]][[1]] ) 

summary (mod.international.2)  # reject non-linear (spline)
cox.zph (mod.international.2)  # if there is evidence of

# Finally, we add shared frailties to the model
mod.international.3.1 <- coxph (Surv(enter.risk.pool, leave.risk.pool, party.death) ~ bank.crisis.in.party.term*log(openk) + bank.crisis.in.party.term*kaopen + grgdpl2 +  log(step.inflation) + log (rgdpl2) + cumulative.bank.crises + pspline(polity2.y) + presidential + I(presidential*log(leave.risk.pool)) + frailty(as.factor(ccname)), data=Imputed.Dataset[[1]][[1]] ) 
mod.international.3.2 <- coxph (Surv(enter.risk.pool, leave.risk.pool, party.death) ~ bank.crisis.in.party.term*log(openk) + bank.crisis.in.party.term*kaopen + grgdpl2 +  log(step.inflation) + log (rgdpl2) + cumulative.bank.crises + pspline(polity2.y) + presidential + I(presidential*log(leave.risk.pool)) + frailty(as.factor(ccname)), data=Imputed.Dataset[[1]][[2]] ) 
mod.international.3.3 <- coxph (Surv(enter.risk.pool, leave.risk.pool, party.death) ~ bank.crisis.in.party.term*log(openk) + bank.crisis.in.party.term*kaopen + grgdpl2 +  log(step.inflation) + log (rgdpl2) + cumulative.bank.crises + pspline(polity2.y) + presidential + I(presidential*log(leave.risk.pool)) + frailty(as.factor(ccname)), data=Imputed.Dataset[[1]][[3]] ) 
mod.international.3.4 <- coxph (Surv(enter.risk.pool, leave.risk.pool, party.death) ~ bank.crisis.in.party.term*log(openk) + bank.crisis.in.party.term*kaopen + grgdpl2 +  log(step.inflation) + log (rgdpl2) + cumulative.bank.crises + pspline(polity2.y) + presidential + I(presidential*log(leave.risk.pool)) + frailty(as.factor(ccname)), data=Imputed.Dataset[[1]][[4]] ) 
mod.international.3.5 <- coxph (Surv(enter.risk.pool, leave.risk.pool, party.death) ~ bank.crisis.in.party.term*log(openk) + bank.crisis.in.party.term*kaopen + grgdpl2 +  log(step.inflation) + log (rgdpl2) + cumulative.bank.crises + pspline(polity2.y) + presidential + I(presidential*log(leave.risk.pool)) + frailty(as.factor(ccname)), data=Imputed.Dataset[[1]][[5]] ) 

summary (mod.international.3.1)  # reject non-linear (spline)
summary (mod.international.3.2)  # reject non-linear (spline)
summary (mod.international.3.3)  # reject non-linear (spline)
summary (mod.international.3.4)  # reject non-linear (spline)
summary (mod.international.3.5)  # reject non-linear (spline)


######################################################################################
# Representative graph for the non-parametric effects of Polity on the log hazard
# Based on code from Keele's book, page 202
library (splines)

# Reestimate the model without frailties, otherwise "termplot" does not work
mod.international.3.1 <- coxph (Surv(enter.risk.pool, leave.risk.pool, party.death) ~ bank.crisis.in.party.term*log(openk) + bank.crisis.in.party.term*kaopen + grgdpl2 +  log(step.inflation) + log (rgdpl2) + cumulative.bank.crises + pspline(polity2.y) + presidential + I(presidential*log(leave.risk.pool)), method="efron", robust=TRUE, data=Imputed.Dataset[[1]][[1]] ) 

pdf ("nonparametric_polity.pdf")
termplot(mod.international.3.1, terms=8, se = TRUE, ylab = "Log Hazard", rug=TRUE, col.term="black", col.se="black", xlab = "Polity IV score", bty="n")
dev.off()

######################################################################################

# Make a list containing all five models
mod.international <- list (mod.international.3.1, mod.international.3.2, mod.international.3.3, mod.international.3.4, mod.international.3.5)

# Combine information from all five models
International.Variables <- MixAmeliaModels (model.name=mod.international, number.imputations=5)

# Extract frailty.names
covariates.in.model <- c("bank.crisis.in.party.term","openk","kaopen","grgdpl2","step.inflation","rgdpl2","cumulative.bank.crises","polity2.y","presidential")
International.Variables.frailties <- ReturnFrailtyNames (covariates.in.model, Data=Imputed.Dataset[[1]][[5]][Imputed.Dataset[[1]][[5]]$democratic.spell==1,])

######################################################################################





####################################################################################
# Trade openness covariate
####################################################################################
# this is the script of what one ought to do according to Keele 2010 (PA)
# Estimate model using splines for continuous independent variables
mod.trade.1 <- coxph (Surv(enter.risk.pool, leave.risk.pool, party.death) ~ bank.crisis.in.party.term + pspline(openk) + pspline(grgdpl2) +  pspline(log(step.inflation)) + pspline(log (rgdpl2)) + cumulative.bank.crises + pspline(polity2.y) + presidential, data=Imputed.Dataset[[1]][[1]] ) 

summary (mod.trade.1)  # reject non-linear (spline) specifications that do not achieve statistical significance

# Only the Polity2.y spline achieves significance
mod.trade.1 <- coxph (Surv(enter.risk.pool, leave.risk.pool, party.death) ~ bank.crisis.in.party.term*openk + grgdpl2 +  log(step.inflation) + log (rgdpl2) + cumulative.bank.crises + pspline(polity2.y) + presidential, data=Imputed.Dataset[[1]][[1]] ) 

summary (mod.trade.1)  # reject non-linear (spline)
cox.zph (mod.trade.1)  # if there is evidence of non-proportionality, then it is necessary to interact offending variable with log.time
# Only presidential fails the test of proportionality at the 95% confidence level

# The next line is the model that one should fit, according to the evidence in the previous lines
mod.trade.2 <- coxph (Surv(enter.risk.pool, leave.risk.pool, party.death) ~ bank.crisis.in.party.term*openk + grgdpl2 +  log(step.inflation) + log (rgdpl2) + cumulative.bank.crises + pspline(polity2.y) + presidential + I(presidential*log(leave.risk.pool)), data=Imputed.Dataset[[1]][[1]] ) 

summary (mod.trade.2)  # reject non-linear (spline)
cox.zph (mod.trade.2)  # if there is evidence of

# Finally, we add shared frailties to the model
mod.trade.3.1 <- coxph (Surv(enter.risk.pool, leave.risk.pool, party.death) ~ bank.crisis.in.party.term*log(openk) + grgdpl2 +  log(step.inflation) + log (rgdpl2) + cumulative.bank.crises + pspline(polity2.y) + presidential + I(presidential*log(leave.risk.pool)) + frailty(as.factor(ccname)), data=Imputed.Dataset[[1]][[1]] ) 
mod.trade.3.2 <- coxph (Surv(enter.risk.pool, leave.risk.pool, party.death) ~ bank.crisis.in.party.term*log(openk) + grgdpl2 +  log(step.inflation) + log (rgdpl2) + cumulative.bank.crises + pspline(polity2.y) + presidential + I(presidential*log(leave.risk.pool)) + frailty(as.factor(ccname)), data=Imputed.Dataset[[1]][[2]] ) 
mod.trade.3.3 <- coxph (Surv(enter.risk.pool, leave.risk.pool, party.death) ~ bank.crisis.in.party.term*log(openk) + grgdpl2 +  log(step.inflation) + log (rgdpl2) + cumulative.bank.crises + pspline(polity2.y) + presidential + I(presidential*log(leave.risk.pool)) + frailty(as.factor(ccname)), data=Imputed.Dataset[[1]][[3]] ) 
mod.trade.3.4 <- coxph (Surv(enter.risk.pool, leave.risk.pool, party.death) ~ bank.crisis.in.party.term*log(openk) + grgdpl2 +  log(step.inflation) + log (rgdpl2) + cumulative.bank.crises + pspline(polity2.y) + presidential + I(presidential*log(leave.risk.pool)) + frailty(as.factor(ccname)), data=Imputed.Dataset[[1]][[4]] ) 
mod.trade.3.5 <- coxph (Surv(enter.risk.pool, leave.risk.pool, party.death) ~ bank.crisis.in.party.term*log(openk) + grgdpl2 +  log(step.inflation) + log (rgdpl2) + cumulative.bank.crises + pspline(polity2.y) + presidential + I(presidential*log(leave.risk.pool)) + frailty(as.factor(ccname)), data=Imputed.Dataset[[1]][[5]] ) 

summary (mod.trade.3.1)  # reject non-linear (spline)
summary (mod.trade.3.2)  # reject non-linear (spline)
summary (mod.trade.3.3)  # reject non-linear (spline)
summary (mod.trade.3.4)  # reject non-linear (spline)
summary (mod.trade.3.5)  # reject non-linear (spline)

######################################################################################

# Make a list containing all five models
mod.trade <- list (mod.trade.3.1, mod.trade.3.2, mod.trade.3.3, mod.trade.3.4, mod.trade.3.5)

# Combine information from all five models
Trade.Variables <- MixAmeliaModels (model.name=mod.trade, number.imputations=5)

# Extract frailty.names
covariates.in.model <- c("bank.crisis.in.party.term","openk","grgdpl2","step.inflation","rgdpl2","cumulative.bank.crises","polity2.y","presidential")
Trade.Variables.frailties <- ReturnFrailtyNames (covariates.in.model, Data=Imputed.Dataset[[1]][[5]][Imputed.Dataset[[1]][[5]]$democratic.spell==1,])

######################################################################################



####################################################################################
# Capital openness covariate
####################################################################################
# this is the script of what one ought to do according to Keele 2010 (PA)
# Estimate model using splines for continuous independent variables
mod.capital.1 <- coxph (Surv(enter.risk.pool, leave.risk.pool, party.death) ~ bank.crisis.in.party.term + pspline(kaopen) + pspline(grgdpl2) +  pspline(log(step.inflation)) + pspline(log (rgdpl2)) + cumulative.bank.crises + pspline(polity2.y) + presidential, data=Imputed.Dataset[[1]][[1]] ) 

summary (mod.capital.1)  # reject non-linear (spline) specifications that do not achieve statistical significance

# Only the Polity2.y spline achieves significance
mod.capital.1 <- coxph (Surv(enter.risk.pool, leave.risk.pool, party.death) ~ bank.crisis.in.party.term*kaopen + grgdpl2 +  log(step.inflation) + log (rgdpl2) + cumulative.bank.crises + pspline(polity2.y) + presidential, data=Imputed.Dataset[[1]][[1]] ) 

summary (mod.capital.1)  # reject non-linear (spline)
cox.zph (mod.capital.1)  # if there is evidence of non-proportionality, then it is necessary to interact offending variable with log.time
# Only presidential fails the test of proportionality at the 95% confidence level

# The next line is the model that one should fit, according to the evidence in the previous lines
mod.capital.2 <- coxph (Surv(enter.risk.pool, leave.risk.pool, party.death) ~ bank.crisis.in.party.term*kaopen + grgdpl2 +  log(step.inflation) + log (rgdpl2) + cumulative.bank.crises + pspline(polity2.y) + presidential + I(presidential*log(leave.risk.pool)), data=Imputed.Dataset[[1]][[1]] ) 

summary (mod.capital.2)  # reject non-linear (spline)
cox.zph (mod.capital.2)  # if there is evidence of

# Finally, we add shared frailties to the model
mod.capital.3.1 <- coxph (Surv(enter.risk.pool, leave.risk.pool, party.death) ~ bank.crisis.in.party.term*kaopen + grgdpl2 +  log(step.inflation) + log (rgdpl2) + cumulative.bank.crises + pspline(polity2.y) + presidential + I(presidential*log(leave.risk.pool)) + frailty(as.factor(ccname)), data=Imputed.Dataset[[1]][[1]] ) 
mod.capital.3.2 <- coxph (Surv(enter.risk.pool, leave.risk.pool, party.death) ~ bank.crisis.in.party.term*kaopen + grgdpl2 +  log(step.inflation) + log (rgdpl2) + cumulative.bank.crises + pspline(polity2.y) + presidential + I(presidential*log(leave.risk.pool)) + frailty(as.factor(ccname)), data=Imputed.Dataset[[1]][[2]] ) 
mod.capital.3.3 <- coxph (Surv(enter.risk.pool, leave.risk.pool, party.death) ~ bank.crisis.in.party.term*kaopen + grgdpl2 +  log(step.inflation) + log (rgdpl2) + cumulative.bank.crises + pspline(polity2.y) + presidential + I(presidential*log(leave.risk.pool)) + frailty(as.factor(ccname)), data=Imputed.Dataset[[1]][[3]] ) 
mod.capital.3.4 <- coxph (Surv(enter.risk.pool, leave.risk.pool, party.death) ~ bank.crisis.in.party.term*kaopen + grgdpl2 +  log(step.inflation) + log (rgdpl2) + cumulative.bank.crises + pspline(polity2.y) + presidential + I(presidential*log(leave.risk.pool)) + frailty(as.factor(ccname)), data=Imputed.Dataset[[1]][[4]] ) 
mod.capital.3.5 <- coxph (Surv(enter.risk.pool, leave.risk.pool, party.death) ~ bank.crisis.in.party.term*kaopen + grgdpl2 +  log(step.inflation) + log (rgdpl2) + cumulative.bank.crises + pspline(polity2.y) + presidential + I(presidential*log(leave.risk.pool)) + frailty(as.factor(ccname)), data=Imputed.Dataset[[1]][[5]] ) 

summary (mod.capital.3.1)  # reject non-linear (spline)
summary (mod.capital.3.2)  # reject non-linear (spline)
summary (mod.capital.3.3)  # reject non-linear (spline)
summary (mod.capital.3.4)  # reject non-linear (spline)
summary (mod.capital.3.5)  # reject non-linear (spline)

######################################################################################

# Make a list containing all five models
mod.capital <- list (mod.capital.3.1, mod.capital.3.2, mod.capital.3.3, mod.capital.3.4, mod.capital.3.5)

# Combine information from all five models
Capital.Variables <- MixAmeliaModels (model.name=mod.capital, number.imputations=5)

# Extract frailty.names
covariates.in.model <- c("bank.crisis.in.party.term","kaopen","grgdpl2","step.inflation","rgdpl2","cumulative.bank.crises","polity2.y","presidential")
Capital.Variables.frailties <- ReturnFrailtyNames (covariates.in.model, Data=Imputed.Dataset[[1]][[5]][Imputed.Dataset[[1]][[5]]$democratic.spell==1,])

######################################################################################


####################################################################################
# Veto (POLCONV) covariates
####################################################################################
# this is the script of what one ought to do according to Keele 2010 (PA)
# Estimate model using splines for continuous independent variables
mod.polconv.1 <- coxph (Surv(enter.risk.pool, leave.risk.pool, party.death) ~ bank.crisis.in.party.term + POLCONV + pspline(grgdpl2) +  pspline(log(step.inflation)) + pspline(log (rgdpl2)) + cumulative.bank.crises + pspline(polity2.y) + presidential, data=Imputed.Dataset[[1]][[1]] ) 

summary (mod.polconv.1)  # reject non-linear (spline) specifications that do not achieve statistical significance

# Polity2.y spline achieves significance
mod.polconv.1 <- coxph (Surv(enter.risk.pool, leave.risk.pool, party.death) ~ bank.crisis.in.party.term*POLCONV + grgdpl2 +  log(step.inflation) + log (rgdpl2) + cumulative.bank.crises + pspline(polity2.y) + presidential, data=Imputed.Dataset[[1]][[1]] ) 

summary (mod.polconv.1)  # reject non-linear (spline)
cox.zph (mod.polconv.1)  # if there is evidence of non-proportionality, then it is necessary to interact offending variable with log.time
# Only presidential fails the test of proportionality at the 95% confidence level

# The next line is the model that one should fit, according to the evidence in the previous lines
mod.polconv.2 <- coxph (Surv(enter.risk.pool, leave.risk.pool, party.death) ~ bank.crisis.in.party.term*POLCONV + grgdpl2 +  log(step.inflation) + log (rgdpl2) + cumulative.bank.crises + pspline(polity2.y) + presidential + I(presidential*log(leave.risk.pool)), data=Imputed.Dataset[[1]][[1]] ) 

summary (mod.polconv.2)  # reject non-linear (spline)
cox.zph (mod.polconv.2)  # if there is evidence of

# Finally, we add shared frailties to the model
mod.polconv.3.1 <- coxph (Surv(enter.risk.pool, leave.risk.pool, party.death) ~ bank.crisis.in.party.term*POLCONV + grgdpl2 +  log(step.inflation) + log (rgdpl2) + cumulative.bank.crises + pspline(polity2.y) + presidential + I(presidential*log(leave.risk.pool)) + frailty(as.factor(ccname)), data=Imputed.Dataset[[1]][[1]] ) 
mod.polconv.3.2 <- coxph (Surv(enter.risk.pool, leave.risk.pool, party.death) ~ bank.crisis.in.party.term*POLCONV + grgdpl2 +  log(step.inflation) + log (rgdpl2) + cumulative.bank.crises + pspline(polity2.y) + presidential + I(presidential*log(leave.risk.pool)) + frailty(as.factor(ccname)), data=Imputed.Dataset[[1]][[2]] ) 
mod.polconv.3.3 <- coxph (Surv(enter.risk.pool, leave.risk.pool, party.death) ~ bank.crisis.in.party.term*POLCONV + grgdpl2 +  log(step.inflation) + log (rgdpl2) + cumulative.bank.crises + pspline(polity2.y) + presidential + I(presidential*log(leave.risk.pool)) + frailty(as.factor(ccname)), data=Imputed.Dataset[[1]][[3]] ) 
mod.polconv.3.4 <- coxph (Surv(enter.risk.pool, leave.risk.pool, party.death) ~ bank.crisis.in.party.term*POLCONV + grgdpl2 +  log(step.inflation) + log (rgdpl2) + cumulative.bank.crises + pspline(polity2.y) + presidential + I(presidential*log(leave.risk.pool)) + frailty(as.factor(ccname)), data=Imputed.Dataset[[1]][[4]] ) 
mod.polconv.3.5 <- coxph (Surv(enter.risk.pool, leave.risk.pool, party.death) ~ bank.crisis.in.party.term*POLCONV + grgdpl2 +  log(step.inflation) + log (rgdpl2) + cumulative.bank.crises + pspline(polity2.y) + presidential + I(presidential*log(leave.risk.pool)) + frailty(as.factor(ccname)), data=Imputed.Dataset[[1]][[5]] ) 

summary (mod.polconv.3.1)
summary (mod.polconv.3.2)
summary (mod.polconv.3.3)
summary (mod.polconv.3.4)
summary (mod.polconv.3.5)

######################################################################################

# Make a list containing all five models
mod.polconv <- list (mod.polconv.3.1, mod.polconv.3.2, mod.polconv.3.3, mod.polconv.3.4, mod.polconv.3.5)

# Combine information from all five models
Polconv.Variables <- MixAmeliaModels (model.name=mod.polconv, number.imputations=5)

# Extract frailty.names
covariates.in.model <- c("bank.crisis.in.party.term","POLCONV","grgdpl2","step.inflation","rgdpl2","cumulative.bank.crises","polity2.y","presidential")
Polconv.Variables.frailties <- ReturnFrailtyNames (covariates.in.model, Data=Imputed.Dataset[[1]][[5]][Imputed.Dataset[[1]][[5]]$democratic.spell==1,])

######################################################################################






####################################################################################
# Allhouse covariate
####################################################################################
# this is the script of what one ought to do according to Keele 2010 (PA)
# Estimate model using splines for continuous independent variables
mod.allhouse.1 <- coxph (Surv(enter.risk.pool, leave.risk.pool, party.death) ~ bank.crisis.in.party.term + allhouse + pspline(grgdpl2) +  pspline(log(step.inflation)) + pspline(log (rgdpl2)) + cumulative.bank.crises + pspline(polity2.y) + presidential, data=Imputed.Dataset[[1]][[1]] ) 

summary (mod.allhouse.1)  # reject non-linear (spline) specifications that do not achieve statistical significance

# Polity2.y spline achieves significance
mod.allhouse.1 <- coxph (Surv(enter.risk.pool, leave.risk.pool, party.death) ~ bank.crisis.in.party.term*allhouse + grgdpl2 +  log(step.inflation) + log (rgdpl2) + cumulative.bank.crises + pspline(polity2.y) + presidential, data=Imputed.Dataset[[1]][[1]] ) 

summary (mod.allhouse.1)  # reject non-linear (spline)
cox.zph (mod.allhouse.1)  # if there is evidence of non-proportionality, then it is necessary to interact offending variable with log.time
# Only presidential fails the test of proportionality at the 95% confidence level

# The next line is the model that one should fit, according to the evidence in the previous lines
mod.allhouse.2 <- coxph (Surv(enter.risk.pool, leave.risk.pool, party.death) ~ bank.crisis.in.party.term*allhouse + grgdpl2 +  log(step.inflation) + log (rgdpl2) + cumulative.bank.crises + pspline(polity2.y) + presidential + I(presidential*log(leave.risk.pool)), data=Imputed.Dataset[[1]][[1]] ) 

summary (mod.allhouse.2)  # reject non-linear (spline)
cox.zph (mod.allhouse.2)  # if there is evidence of

# Finally, we add shared frailties to the model
mod.allhouse.3.1 <- coxph (Surv(enter.risk.pool, leave.risk.pool, party.death) ~ bank.crisis.in.party.term*allhouse + grgdpl2 +  log(step.inflation) + log (rgdpl2) + cumulative.bank.crises + pspline(polity2.y) + presidential + I(presidential*log(leave.risk.pool)) + frailty(as.factor(ccname)), data=Imputed.Dataset[[1]][[1]] ) 
mod.allhouse.3.2 <- coxph (Surv(enter.risk.pool, leave.risk.pool, party.death) ~ bank.crisis.in.party.term*allhouse + grgdpl2 +  log(step.inflation) + log (rgdpl2) + cumulative.bank.crises + pspline(polity2.y) + presidential + I(presidential*log(leave.risk.pool)) + frailty(as.factor(ccname)), data=Imputed.Dataset[[1]][[2]] ) 
mod.allhouse.3.3 <- coxph (Surv(enter.risk.pool, leave.risk.pool, party.death) ~ bank.crisis.in.party.term*allhouse + grgdpl2 +  log(step.inflation) + log (rgdpl2) + cumulative.bank.crises + pspline(polity2.y) + presidential + I(presidential*log(leave.risk.pool)) + frailty(as.factor(ccname)), data=Imputed.Dataset[[1]][[3]] ) 
mod.allhouse.3.4 <- coxph (Surv(enter.risk.pool, leave.risk.pool, party.death) ~ bank.crisis.in.party.term*allhouse + grgdpl2 +  log(step.inflation) + log (rgdpl2) + cumulative.bank.crises + pspline(polity2.y) + presidential + I(presidential*log(leave.risk.pool)) + frailty(as.factor(ccname)), data=Imputed.Dataset[[1]][[4]] ) 
mod.allhouse.3.5 <- coxph (Surv(enter.risk.pool, leave.risk.pool, party.death) ~ bank.crisis.in.party.term*allhouse + grgdpl2 +  log(step.inflation) + log (rgdpl2) + cumulative.bank.crises + pspline(polity2.y) + presidential + I(presidential*log(leave.risk.pool)) + frailty(as.factor(ccname)), data=Imputed.Dataset[[1]][[5]] ) 

summary (mod.allhouse.3.1)
summary (mod.allhouse.3.2)
summary (mod.allhouse.3.3)
summary (mod.allhouse.3.4)
summary (mod.allhouse.3.5)

######################################################################################

# Make a list containing all five models
mod.allhouse <- list (mod.allhouse.3.1, mod.allhouse.3.2, mod.allhouse.3.3, mod.allhouse.3.4, mod.allhouse.3.5)

# Combine information from all five models
Allhouse.Variables <- MixAmeliaModels (model.name=mod.allhouse, number.imputations=5)

# Extract frailty.names
covariates.in.model <- c("bank.crisis.in.party.term","allhouse","grgdpl2","step.inflation","rgdpl2","cumulative.bank.crises","polity2.y","presidential")
Allhouse.Variables.frailties <- ReturnFrailtyNames (covariates.in.model, Data=Imputed.Dataset[[1]][[5]][Imputed.Dataset[[1]][[5]]$democratic.spell==1,])

######################################################################################



####################################################################################
# Clarity of responsibility covariate
####################################################################################
# this is the script of what one ought to do according to Keele 2010 (PA)
Short.Data$id <- paste (Short.Data$ccname, Short.Data$year.x, sep="_")
imputation.id <- paste (Imputed.Dataset[[1]][[1]]$ccname, Imputed.Dataset[[1]][[1]]$year.x, sep="_")
x <- Short.Data$id[!is.na(Short.Data$clarity.responsibility)]
z <- seq(1, length(imputation.id), by=1)[is.element(imputation.id,x)]

# Estimate model using splines for continuous independent variables
mod.clarity.1 <- coxph (Surv(enter.risk.pool, leave.risk.pool, party.death) ~ bank.crisis.in.party.term*clarity.responsibility + pspline(grgdpl2) +  pspline(log(step.inflation)) + pspline(log (rgdpl2)) + cumulative.bank.crises + pspline(polity2.y), data=Imputed.Dataset[[1]][[1]][z,] ) 

summary (mod.clarity.1)  # reject non-linear (spline) specifications that do not achieve statistical significance

# Polity2.y and clarity splines achieve significance
mod.clarity.1 <- coxph (Surv(enter.risk.pool, leave.risk.pool, party.death) ~ bank.crisis.in.party.term*clarity.responsibility + grgdpl2 +  log(step.inflation) + log (rgdpl2) + cumulative.bank.crises + pspline(polity2.y), data=Imputed.Dataset[[1]][[1]][z,] ) 

summary (mod.clarity.1)  # reject non-linear (spline)
cox.zph (mod.clarity.1)  # if there is evidence of non-proportionality, then it is necessary to interact offending variable with log.time
# Only presidential fails the test of proportionality at the 95% confidence level

# The next line is the model that one should fit, according to the evidence in the previous lines
mod.clarity.2 <- coxph (Surv(enter.risk.pool, leave.risk.pool, party.death) ~ bank.crisis.in.party.term*clarity.responsibility + grgdpl2 +  log(step.inflation) + log (rgdpl2) + cumulative.bank.crises + pspline(polity2.y), data=Imputed.Dataset[[1]][[1]][z,] ) 

summary (mod.clarity.2)  # reject non-linear (spline)
cox.zph (mod.clarity.2)  # if there is evidence of

# Finally, we add shared frailties to the model
mod.clarity.3.1 <- coxph (Surv(enter.risk.pool, leave.risk.pool, party.death) ~ bank.crisis.in.party.term*clarity.responsibility + grgdpl2 +  log(step.inflation) + log (rgdpl2) + cumulative.bank.crises + pspline(polity2.y) + frailty(as.factor(ccname)), data=Imputed.Dataset[[1]][[1]][z,] ) 
mod.clarity.3.2 <- coxph (Surv(enter.risk.pool, leave.risk.pool, party.death) ~ bank.crisis.in.party.term*clarity.responsibility + grgdpl2 +  log(step.inflation) + log (rgdpl2) + cumulative.bank.crises + pspline(polity2.y) + frailty(as.factor(ccname)), data=Imputed.Dataset[[1]][[2]][z,] ) 
mod.clarity.3.3 <- coxph (Surv(enter.risk.pool, leave.risk.pool, party.death) ~ bank.crisis.in.party.term*clarity.responsibility + grgdpl2 +  log(step.inflation) + log (rgdpl2) + cumulative.bank.crises + pspline(polity2.y) + frailty(as.factor(ccname)), data=Imputed.Dataset[[1]][[3]][z,] ) 
mod.clarity.3.4 <- coxph (Surv(enter.risk.pool, leave.risk.pool, party.death) ~ bank.crisis.in.party.term*clarity.responsibility + grgdpl2 +  log(step.inflation) + log (rgdpl2) + cumulative.bank.crises + pspline(polity2.y) + frailty(as.factor(ccname)), data=Imputed.Dataset[[1]][[4]][z,] ) 
mod.clarity.3.5 <- coxph (Surv(enter.risk.pool, leave.risk.pool, party.death) ~ bank.crisis.in.party.term*clarity.responsibility + grgdpl2 +  log(step.inflation) + log (rgdpl2) + cumulative.bank.crises + pspline(polity2.y) + frailty(as.factor(ccname)), data=Imputed.Dataset[[1]][[5]][z,] ) 

summary (mod.clarity.3.1)
summary (mod.clarity.3.2)
summary (mod.clarity.3.3)
summary (mod.clarity.3.4)
summary (mod.clarity.3.5)

######################################################################################

# Make a list containing all five models
mod.clarity <- list (mod.clarity.3.1, mod.clarity.3.2, mod.clarity.3.3, mod.clarity.3.4, mod.clarity.3.5)

# Combine information from all five models
Clarity.Variables <- MixAmeliaModels (model.name=mod.clarity, number.imputations=5)
 
# Extract frailty.names
covariates.in.model <- c("bank.crisis.in.party.term","clarity.responsibility","grgdpl2","step.inflation","rgdpl2","cumulative.bank.crises","polity2.y","presidential")
Clarity.Variables.frailties <- ReturnFrailtyNames (covariates.in.model, Data=Imputed.Dataset[[1]][[5]][Imputed.Dataset[[1]][[5]]$democratic.spell==1,])

######################################################################################




####################################################################################
# global.crisis covariate
####################################################################################
# this is the script of what one ought to do according to Keele 2010 (PA)
# Estimate model using splines for continuous independent variables

crisis <- ifelse (Imputed.Dataset[[1]][[1]][,27]==0, 0, ifelse (Imputed.Dataset[[1]][[1]][,27] > 0 & Imputed.Dataset[[1]][[1]][,33]==1, 1, 2)) 
crisis <- as.factor (crisis)
mod.global.crisis.1 <- coxph (Surv(enter.risk.pool, leave.risk.pool, party.death) ~ as.factor (crisis) + pspline(grgdpl2) +  pspline(log(step.inflation)) + pspline(log (rgdpl2)) + cumulative.bank.crises + pspline(polity2.y) + presidential, data=Imputed.Dataset[[1]][[1]] ) 

summary (mod.global.crisis.1)  # reject non-linear (spline) specifications that do not achieve statistical significance

# Polity2.y splines achieve significance
mod.global.crisis.1 <- coxph (Surv(enter.risk.pool, leave.risk.pool, party.death) ~ as.factor (crisis) + grgdpl2 +  log(step.inflation) + log (rgdpl2) + cumulative.bank.crises + pspline(polity2.y) + presidential, data=Imputed.Dataset[[1]][[1]] ) 

summary (mod.global.crisis.1)  # reject non-linear (spline)
cox.zph (mod.global.crisis.1)  # if there is evidence of non-proportionality, then it is necessary to interact offending variable with log.time
# Only presidential fails the test of proportionality at the 95% confidence level

# The next line is the model that one should fit, according to the evidence in the previous lines
mod.global.crisis.2 <- coxph (Surv(enter.risk.pool, leave.risk.pool, party.death) ~ as.factor (crisis) + grgdpl2 +  log(step.inflation) + log (rgdpl2) + cumulative.bank.crises + pspline(polity2.y) + presidential + I(presidential*log(leave.risk.pool)), data=Imputed.Dataset[[1]][[1]] ) 

summary (mod.global.crisis.2)  # reject non-linear (spline)
cox.zph (mod.global.crisis.2)  # if there is evidence of

# Finally, we add shared frailties to the model
mod.global.crisis.3.1 <- coxph (Surv(enter.risk.pool, leave.risk.pool, party.death) ~ as.factor (crisis) + grgdpl2 +  log(step.inflation) + log (rgdpl2) + cumulative.bank.crises + pspline(polity2.y) + presidential + I(presidential*log(leave.risk.pool)) + frailty(as.factor(ccname)), data=Imputed.Dataset[[1]][[1]] ) 
mod.global.crisis.3.2 <- coxph (Surv(enter.risk.pool, leave.risk.pool, party.death) ~ as.factor (crisis) + grgdpl2 +  log(step.inflation) + log (rgdpl2) + cumulative.bank.crises + pspline(polity2.y) + presidential + I(presidential*log(leave.risk.pool)) + frailty(as.factor(ccname)), data=Imputed.Dataset[[1]][[2]] ) 
mod.global.crisis.3.3 <- coxph (Surv(enter.risk.pool, leave.risk.pool, party.death) ~ as.factor (crisis) + grgdpl2 +  log(step.inflation) + log (rgdpl2) + cumulative.bank.crises + pspline(polity2.y) + presidential + I(presidential*log(leave.risk.pool)) + frailty(as.factor(ccname)), data=Imputed.Dataset[[1]][[3]] ) 
mod.global.crisis.3.4 <- coxph (Surv(enter.risk.pool, leave.risk.pool, party.death) ~ as.factor (crisis) + grgdpl2 +  log(step.inflation) + log (rgdpl2) + cumulative.bank.crises + pspline(polity2.y) + presidential + I(presidential*log(leave.risk.pool)) + frailty(as.factor(ccname)), data=Imputed.Dataset[[1]][[4]] ) 
mod.global.crisis.3.5 <- coxph (Surv(enter.risk.pool, leave.risk.pool, party.death) ~ as.factor (crisis) + grgdpl2 +  log(step.inflation) + log (rgdpl2) + cumulative.bank.crises + pspline(polity2.y) + presidential + I(presidential*log(leave.risk.pool)) + frailty(as.factor(ccname)), data=Imputed.Dataset[[1]][[5]] ) 

summary (mod.global.crisis.3.1)
summary (mod.global.crisis.3.2)
summary (mod.global.crisis.3.3)
summary (mod.global.crisis.3.4)
summary (mod.global.crisis.3.5)

######################################################################################

# Make a list containing all five models
mod.global.crisis <- list (mod.global.crisis.3.1, mod.global.crisis.3.2, mod.global.crisis.3.3, mod.global.crisis.3.4, mod.global.crisis.3.5)

# Combine information from all five models
Global.Crisis.Variables <- MixAmeliaModels (model.name=mod.global.crisis, number.imputations=5)

# Extract frailty.names
covariates.in.model <- c("bank.crisis.in.party.term","non.global.crisis","grgdpl2","step.inflation","rgdpl2","cumulative.bank.crises","polity2.y","presidential")
Global.Crisis.Variables.frailties <- ReturnFrailtyNames (covariates.in.model, Data=Imputed.Dataset[[1]][[5]][Imputed.Dataset[[1]][[5]]$democratic.spell==1,])

######################################################################################


# Frailty plot for show

pdf ("frailty_example.pdf")
plot (c(1,91), c(min(Polconv.Variables$frailties), max(Polconv.Variables$frailties)), axes=F, type="n", xlab="Shared frailties (arranged alphabetically)", ylab="Log Hazard")
axis (2)
axis (1, labels=c(NA,NA), at=c(1,91))
text (x=1:91, y=Polconv.Variables$frailties, labels=Polconv.Variables.frailties, cex=0.7)
dev.off()
